@@ -1,15 +1,16 @@
+import functools
 import logging
+import math
 import os
 import time
-from pathlib import Path
 from datetime import datetime
-import math
+from pathlib import Path
 
-import functools
-import torch
-import tqdm
-from IPython.core.display import HTML, display
 import numpy as np
+import torch
+
+from IPython.core.display import HTML, display
+
 from . import drawers
 
 
@@ -63,27 +64,31 @@ class Miner(object):
             hooks and plugins the same time.
     """
 
-    def __init__(self, alchemistic_directory, model, optimizer, loss_func,
-                 code="geass", train_dataloader=None, val_dataloader=None,
-                 resume=True, eval_stride=1, persist_stride=1, gpu=True,
-                 drawer='matplotlib', hooks={}, max_epochs=None, statable={},
-                 logging_format=None, trival=False, in_notebook=False, plugins=[],
-                 logger=None, sheet=None, accumulated_iter=1):
+    def __init__(
+            self, alchemistic_directory, model, optimizer, loss_func,
+            code="geass", train_dataloader=None, val_dataloader=None,
+            resume=True, eval_stride=1, persist_stride=1, gpu=True,
+            drawer='matplotlib', hooks={}, max_epochs=None, statable={},
+            logging_format=None, trival=False, in_notebook=False, plugins=[],
+            logger=None, sheet=None, accumulated_iter=1, ignore_optimizer_resume=False):
         self.alchemistic_directory = alchemistic_directory
         self.code = code
+        if trival:
+            self.code = f'trival_{code}'
         self.create_dirs()
         self.gpu = gpu
         self.devices = torch.device("cuda" if torch.cuda.is_available() else "cpu")
         self.logger = logger
-        self.code_dir = os.path.join(alchemistic_directory, code)
+        self.code_dir = os.path.join(alchemistic_directory, self.code)
         if self.logger is None:
-            self.set_logging_config(alchemistic_directory, code, logging_format)
+            self.set_logging_config(alchemistic_directory, self.code, logging_format)
             self.logger = logging
         self.create_drawer(drawer)
-        self.models_dir = os.path.join(alchemistic_directory, code, 'models')
+        self.models_dir = os.path.join(alchemistic_directory, self.code, 'models')
         self.in_notebook = in_notebook
         self.statable = statable
         self.accumulated_iter = float(accumulated_iter)
+        self.ignore_optimizer_resume = ignore_optimizer_resume
 
         self.model = model
         self.optimizer = optimizer
@@ -171,8 +176,7 @@ class Miner(object):
 
     def create_drawer(self, drawer):
         if drawer == 'tensorboard':
-            self.drawer = drawers.TensorboardDrawer(
-                self.alchemistic_directory, self.code)
+            self.drawer = drawers.TensorboardDrawer(self)
         elif drawer == 'matplotlib':
             self.drawer = drawers.MatplotlibDrawer(self)
         else:
@@ -236,11 +240,11 @@ class Miner(object):
             self.logger.info(msg)
             self.notebook_output(msg)
             checkpoint = torch.load(checkpoint_path)
-            self.current_epoch = checkpoint['epoch']
-            self.current_train_iteration = checkpoint['train_iteration']
-            self.current_val_iteration = checkpoint['val_iteration']
-            self.lowest_train_loss = checkpoint['lowest_train_loss']
-            self.lowest_val_loss = checkpoint['lowest_val_loss']
+            self.current_epoch = checkpoint.get('epoch', 0)
+            self.current_train_iteration = checkpoint.get('train_iteration', 0)
+            self.current_val_iteration = checkpoint.get('val_iteration', 0)
+            self.lowest_train_loss = checkpoint.get('lowest_train_loss', 9999)
+            self.lowest_val_loss = checkpoint.get('lowest_val_loss', 9999)
 
             try:
                 self.model.load_state_dict(checkpoint['state_dict'], strict=True)
@@ -252,7 +256,7 @@ class Miner(object):
                 self.notebook_output(msg)
                 self.model.load_state_dict(checkpoint['state_dict'], strict=False)
 
-            if 'optimizer' in checkpoint:
+            if 'optimizer' in checkpoint and not self.ignore_optimizer_resume:
                 try:
                     self.optimizer.load_state_dict(checkpoint['optimizer'])
                 except:
@@ -359,7 +363,7 @@ class Miner(object):
                                      f'finished, loss is {total_val_loss}')
             if self.drawer is not None:
                 png_file = self.drawer.scalars(
-                    {'train': total_train_loss, 'val': total_val_loss}, 'loss'
+                    self.current_epoch, {'train': total_train_loss, 'val': total_val_loss}, 'loss'
                 )
                 if png_file is not None:
                     self.update_sheet('loss', {'raw': png_file, 'processor': 'upload_image'})
@@ -407,6 +411,7 @@ class Miner(object):
         predict = self.model(data[0].to(self.devices))
         # for the last batch, loss is not supposed divide by self.accumulated_iter
         # just ignored this tiny issue
+        # loss = self.loss_func(predict, *data[1:])
         loss = self.loss_func(predict, data[1].to(self.devices))
         seperate_loss = loss / self.accumulated_iter
         seperate_loss.backward()
@@ -435,6 +440,7 @@ class Miner(object):
             iteration=self.current_val_iteration
         )
         predict = self.model(data[0].to(self.devices))
+        # loss = self.loss_func(predict, *data[1:])
         loss = self.loss_func(predict, data[1].to(self.devices))
         loss = loss.detach().cpu().item()
         self.logger.info('[val {}/{}/{}] loss {}'.format(
