@@ -4,9 +4,10 @@ from pathlib import Path
 
 class Plugin():
 
-    def __init__(self):
+    def __init__(self, prefix=''):
         self.name = self.__class__.__name__
         self.miner = None
+        self.prefix = prefix
 
     def before_hook(self, hook_name, payload):
         return True
@@ -44,3 +45,12 @@ class Plugin():
 
     def plugin_file(self, name):
         return os.path.join(self.plugin_dir, name)
+
+    def create_sheet_column(self, key, name):
+        self.miner.create_sheet_column(f'{self.prefix}{key}', f'{self.prefix}{name}')
+
+    def update_sheet(self, key, value):
+        self.miner.update_sheet(f'{self.prefix}{key}', value)
+
+    def scalars(self, values, graph):
+        return self.miner.drawer.scalars(self.miner.current_epoch, values, f'{self.prefix}{graph}')
